import pico from "picocolors";
import consola from "consola";
import npmKeyword from "npm-keyword";
import packageJson from "package-json";
import inquirer from "inquirer";
import inquirerPrompt from "inquirer-autocomplete-prompt";
import { run, getPkgInfoList } from "../utils/index.mjs";
inquirer.registerPrompt("autocomplete", inquirerPrompt);
const typeMap = [
  { name: "dependencies", value: "--save-prod" },
  { name: "devDependencies", value: "--save-dev" }
];
const addPackage = async (options) => {
  const { targetDirList } = options;
  const appList = await getPkgInfoList(targetDirList);
  const { appName, installPkgName, type } = await inquirer.prompt([
    {
      type: "list",
      name: "appName",
      message: "\u54EA\u4E2A\u9879\u76EE\u9700\u8981\u5B89\u88C5\u4F9D\u8D56\u5305\uFF1F",
      choices: appList.map((i) => ({ value: i.pkgName, name: i.pkgName }))
    },
    {
      type: "autocomplete",
      name: "installPkgName",
      message: "\u8F93\u5165\u9700\u8981\u5B89\u88C5\u7684\u4F9D\u8D56\u5305\u540D\u79F0",
      source: async (answersSoFar, input) => {
        if (!input || !input.trim()) {
          return [];
        }
        const response2 = await npmKeyword(input.trim());
        return response2.map((i) => ({ value: i.name, name: i.name }));
      },
      suggestOnly: true,
      searchText: "\u6B63\u5728\u4ECEnpm\u4E0A\u67E5\u627E\u8BE5\u5305...",
      emptyText: "\u6682\u65E0\u6570\u636E"
    },
    {
      type: "list",
      name: "type",
      message: `\u4F9D\u8D56\u5305\u5B89\u88C5\u5230\u54EA\u91CC\uFF1F ${pico.red(
        "[\u6CE8\u610F: typescript\u7C7B\u578B\u5305\u8BF7\u5B89\u88C5\u5230devDependencies]"
      )}`,
      choices: typeMap.map((i) => ({ name: i.name, value: i.name }))
    }
  ]);
  const pkgJson = await packageJson(installPkgName, { fullMetadata: true });
  const isTypeScriptPkg = Boolean(pkgJson.types || pkgJson.typings);
  if (!isTypeScriptPkg) {
    consola.start(
      pico.yellow(
        `\u5F53\u524D\u4E0B\u8F7D\u7684\u5305 ${pico.cyan(
          installPkgName
        )} \u6CA1\u6709\u5185\u7F6ETypeScript\u7C7B\u578B\u6587\u4EF6\uFF0C\u6B63\u5728\u641C\u5BFB\u7C7B\u578B\u5B9A\u4E49\u6587\u4EF6 ${`@types/${installPkgName.trim()}`}`
      )
    );
  }
  const response = await packageJson(`@types/${installPkgName.trim()}`);
  console.log(response);
  if (response) {
    consola.info(response);
  }
  const { yes } = await inquirer.prompt([
    {
      type: "confirm",
      name: "yes",
      message: `\u786E\u5B9A\u5B89\u88C5 ${pico.yellow(installPkgName)} \u5230 ${pico.magenta(
        appName
      )} ${pico.cyan(type)}?`
    }
  ]);
  const typeValue = typeMap.find((i) => i.name === type)?.value;
  if (yes) {
    console.log(
      `\u6267\u884C ${pico.cyan(
        `pnpm add ${installPkgName} ${typeValue} --filter ${appName}`
      )}`
    );
    await run("pnpm", [
      "add",
      `${installPkgName}`,
      `${typeValue}`,
      "--filter",
      `${appName}`
    ]);
  } else {
    console.log(pico.red("\u53D6\u6D88\u5B89\u88C5"));
  }
  console.log();
};
var addPackage_default = addPackage;
export {
  addPackage_default as default
};
