import path from "node:path";
import fs from "fs-extra";
import pico from "picocolors";
import consola from "consola";
import inquirer from "inquirer";
import fuzzypath from "inquirer-fuzzy-path";
import { glob } from "glob";
inquirer.registerPrompt("fuzzypath", fuzzypath);
const changeExtname = async (options) => {
  let { input, output, originExt, targetExt } = options;
  if (!input || !output || !originExt || !targetExt) {
    const answer = await inquirer.prompt(
      [
        !input && {
          type: "fuzzypath",
          name: "input",
          excludePath: (nodePath) => nodePath.startsWith("node_modules"),
          itemType: "directory",
          rootPath: "./",
          message: "\u8BF7\u9009\u62E9\u8F93\u5165\u76EE\u5F55\u8DEF\u5F84",
          suggestOnly: false,
          depthLimit: void 0
        },
        !output && {
          type: "fuzzypath",
          name: "output",
          excludePath: (nodePath) => nodePath.startsWith("node_modules"),
          itemType: "directory",
          rootPath: "./",
          message: "\u8BF7\u9009\u62E9\u8F93\u51FA\u76EE\u5F55\u8DEF\u5F84",
          suggestOnly: false,
          depthLimit: void 0
        },
        !originExt && {
          type: "input",
          name: "translateModulesStr",
          message: "\u8BF7\u8F93\u5165\u539F\u59CB\u540E\u7F00\u540D",
          validate: function(v) {
            if (!v) {
              return "\u540E\u7F00\u540D\u4E0D\u80FD\u4E3A\u7A7A!";
            }
            return true;
          }
        },
        !targetExt && {
          type: "input",
          name: "translateModulesStr",
          message: "\u8BF7\u8F93\u5165\u76EE\u6807\u540E\u7F00\u540D",
          validate: function(v) {
            if (!v) {
              return "\u540E\u7F00\u540D\u4E0D\u80FD\u4E3A\u7A7A!";
            }
            return true;
          }
        }
      ].filter(Boolean)
    );
    input = answer.input;
    output = answer.output;
    originExt = answer.originExt;
    targetExt = answer.targetExt;
  }
  const inputDirPath = path.resolve(process.cwd(), input);
  const outputDirPath = path.resolve(process.cwd(), output);
  console.log(
    `
\u8F93\u5165\u76EE\u5F55\u8DEF\u5F84: ${pico.green(inputDirPath)}
\u8F93\u51FA\u76EE\u5F55\u8DEF\u5F84: ${pico.green(outputDirPath)}
\u539F\u59CB\u540E\u7F00\u540D: ${pico.green(originExt)}
\u76EE\u6807\u540E\u7F00\u540D: ${pico.green(targetExt)}
  `
  );
  consola.start("\u5F00\u59CB\u8BFB\u53D6\u6587\u4EF6...");
  const filePathList = await glob(`${inputDirPath}/**/*`, { nodir: true });
  const originFilePathList = [];
  const otherFilePathList = [];
  filePathList.forEach((_path) => {
    const filePath = path.resolve(_path);
    if (path.extname(filePath) === originExt) {
      originFilePathList.push(filePath);
    } else {
      otherFilePathList.push(filePath);
    }
  });
  consola.success(
    pico.cyan(
      `\u8BFB\u53D6\u5230 ${originFilePathList.length} \u4E2A\u6587\u4EF6\u5F85\u8F6C\u6362\uFF1B ${originFilePathList.length} \u4E2A\u5176\u4ED6\u7C7B\u578B\u6587\u4EF6\u65E0\u9700\u8F6C\u6362`
    )
  );
  consola.start("\u5F00\u59CB\u8F6C\u6362\u6587\u4EF6...");
  await Promise.all(
    originFilePathList.map((_filePath) => {
      const newFilePath = _filePath.replace(inputDirPath, outputDirPath).replace(originExt, targetExt);
      return fs.copy(_filePath, newFilePath);
    })
  );
  consola.success(pico.cyan(`\u8F6C\u6362\u5B8C\u6210\uFF01`));
  consola.start("\u590D\u5236\u5176\u4ED6\u7C7B\u578B\u6587\u4EF6\u5230\u5B58\u50A8\u76EE\u5F55...");
  await Promise.all(
    otherFilePathList.map((_filePath) => {
      const newFilePath = _filePath.replace(inputDirPath, outputDirPath);
      return fs.copy(_filePath, newFilePath);
    })
  );
  consola.success(pico.cyan(`\u590D\u5236\u5B8C\u6210\uFF01`));
};
var changeExtname_default = changeExtname;
export {
  changeExtname_default as default
};
